#
# spec file for package python-mpmath
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-mpmath
Version:        1.3.0
Release:        1.5
Summary:        Python library for arbitrary-precision floating-point arithmetic
License:        BSD-3-Clause
Group:          Development/Libraries/Python
URL:            https://github.com/fredrik-johansson/mpmath
Source:         https://files.pythonhosted.org/packages/source/m/mpmath/mpmath-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module gmpy2 >= 2.1.0a4}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python >= 3.8
Requires:       python-gmpy2 >= 2.1.0a4
BuildArch:      noarch
%python_subpackages

%description
Mpmath is a pure-Python library for multiprecision floating-point
arithmetic. It provides a set of transcendental functions,
unlimited exponent sizes, complex numbers, interval arithmetic,
numerical integration and differentiation, root-finding, linear
algebra, and others. Almost any calculation can be performed just
as well at 10-digit or 1000-digit precision, and in many cases, mpmath
implements algorithms that scale well for high precision work.
If available, mpmath will (optionally) use gmpy to speed up high
precision operations.

%prep
%setup -q -n mpmath-%{version}
sed -i 's/\r//' mpmath/tests/runtests.py  # fix wrong-script-end-of-line-encoding rpmlint warning
sed -i '1d' mpmath/tests/runtests.py  # fix non-executable-script rpmlint warning

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONDONTWRITEBYTECODE=1
%python_expand PYTHONPATH="%{buildroot}%{$python_sitelib}" py.test-%{$python_bin_suffix} -v --pyargs mpmath

%files %{python_files}
%license LICENSE
%doc README.rst
%dir %{python_sitelib}/mpmath
%{python_sitelib}/mpmath
%{python_sitelib}/mpmath-%{version}-py*.egg-info

%changelog
* Wed Sep 27 2023 ecsos <ecsos@opensuse.org>
- Update to 1.3.0 (bsc#1215804, CVE-2021-29063):
  * Security issues:
  - Fixed ReDOS vulnerability in mpmathify() (CVE-2021-29063)
  * Features:
  - Added quadsubdiv() for numerical integration with adaptive path splitting
  - Added the Cohen algorithm for inverse Laplace transforms
  - Some speedup of matrix multiplication
  - Optimizations to Carlson elliptic integrals
  - Added signal functions (squarew(), trianglew(), sawtoothw(), unit_triangle()
    sigmoidw())
  * Bug fixes:
  - Correct mpf initialization from tuple for finf and fninf
  - Support QR decomposition for matrices of width 0 and 1
  - Fixed some cases where elliprj() gave inaccurate results
  - Fixed cases where digamma() hangs for complex input
  - Fixed cases of polylog() with integer-valued parameter with complex type
  - Fixed fp.nsum() with Euler-Maclaurin algorithm
  * Maintenance:
  - Dropped support for Python 3.4
  - Documentation cleanup
  - Removed obsolete files
  - Added options to runtests.py to skip tests and exit on failure
- Add %%{?sle15_python_module_pythons}
* Tue Jan 10 2023 Daniel Garcia <daniel.garcia@suse.com>
- Replace python-gmpy dependecy with python-gmpy2
* Mon Oct 17 2022 pgajdos@suse.com
- python-six is not required
* Sun Apr  4 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * added requirement for setuptools_scm
- update to version 1.2.1:
  * Add step to publish package on PyPI
  * Make package while CI run
- changes from version 1.2.0:
  * Features and optimizations:
    + Support @ operator for matrix multiplication (Max Gaukler)
    + Add eta() implementing the Dedekind eta function
    + Optimized the python_trailing function (adhoc-king)
    + Implement unary plus for matrices (Max Gaukler)
    + Improved calculation of gram_index (p15-git-acc)
  * Compatibility:
    + Enable sage backend by default only if SAGE_ROOT is set (Pauli
    Virtanen)
    + Fix syntax warnings on CPython 3.8 (Sergey B Kirpichev)
    + Changed version requirements to Python 2.7 and 3.4 or later
    (Sergey B Kirpichev)
    + Improvements to the setup and test code (Sergey B Kirpichev)
    + Fix sys.version comparisons for compatibility with Python 3.10
    (Jakub Wilk)
    + Fixes to Python2/3 compatibility for printing (Christian Clauss)
  * Bug fixes:
    + Fix a possible division by zero in shanks() (Pascal Hebbeker)
    + Fixed indexing errors in deHoog, Knight & Stokes inverse laplace
    transform algorithm (Kris Kuhlman)
    + Corrected branch cuts of the elliprj() function in some cases
    + Fix initialization of iv.matrix from non-interval matrix (Max
    Gaukler)
    + Preserve function signatures in PrecisionManager (Viet Tran)
    + Implemented float and complex conversions for ivmpf (Jonathan
    Warner)
    + Fixed issue with scalar-matrix multiplication for interval
    matrices (Jonathan Warner)
    + Fix estimation of quadrature error with multiple subintervals
    (Tom Minka)
    + Fixed a problem with the defun decorators (Sergey B Kirpichev)
    + Fix eigenvalue sorting by absolute value (Georg Ostrovski)
  * Cleanup:
    + Documentation corrections (Paul Masson, S.Y. Lee)
    + Remove inaccessible logic in fsum/fdot (Sergey B Kirpichev)
    + Remove broken force_type option for matrix constructor (Max
    Gaukler)
    + Fix text of the BSD license in LICENSE (Sergey B Kirpichev)
    + Minor code cleanup (Frédéric Chapoton)
    + Removed old, unused code
* Wed Feb 20 2019 Jan Engelhardt <jengelh@inai.de>
- Trim extreme wording and unspecific comparisons.
* Wed Feb 20 2019 Tomáš Chvátal <tchvatal@suse.com>
- Run tests
* Sat Jan 26 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * update tar.gz name mpmath-all ->mpmath
  * be more specific in %%file section
  * remove devel from noarch package
  * disabled building of doc, not in tar ball at the moment
  * commented out README.rst, also missing in tar-ball
- update to version 1.1.0:
  * Bugs:
    + Fixed severe bug in householder() for complex matrices (Michael
    Kagalenko)
    + Fixed frequently-reported bug where findroot() mysteriously
    raised UnboundLocalError (Sergey B Kirpichev)
    + Corrected rounding in binary-to-decimal conversion above 500
    digits
    + Fixed minor loss of accuracy affecting rf(), ff(), binomial(),
    beta()
    + Fixed incorrect computation of the Hurwitz zeta function in some
    cases
    + Fixed accuracy of digamma function near 0
    + Fixed RuntimeError in qfac() in Python 3.7 caused by raising
    StopIteration (Zbigniew Jędrzejewski-Szmek)
    + Fix to allow NumPy arrays in fdot() (Nico Schlömer)
  * Features and improvements:
    + Added more automatic conversions from Fraction, Decimal, NumPy
    types (Jonathan Warner)
    + Support creating mpf from a long literal (ylemkimon)
    + Implemented log1p()
    + Slight speedup of eig()
    + Implement polylog() for general complex s and z by using Hurwitz
    zeta algorithm as a fallback
  * Library:
    + Test more CPython and PyPy versions (Sergey B Kirpichev, Aaron
    Meurer)
    + Drop support for Python 2.6 and 3.2 (Sergey B Kirpichev)
    + Use py.test for test code; lots of code cleanup (Sergey B
    Kirpichev)
    + Corrections to the documentation (Paul Masson, Connor Behan,
    Warren Weckesser, Aaron Meurer)
- changes from version 1.0.0:
  * Bumped to major version number for 10 year anniversary
  * Added module for inverse Laplace transforms, including the top
    level function invertlaplace() as well as several different
    algorithms (Talbot, Gaver-Stehfest and de Hoog) implemented in
    mpmath.calculus.inverselaplace (Kris Kuhlman)
  * Fixed bugs in elliprg() giving incorrect values for certain input
  * Fixed wrong degree 1 nodes for Gaussian quadrature
  * Made make acot(0) and acoth(0) return a finite result
  * Fixed sieved zeta sum not being used in Python 3, and added cutoff
    for sieved zeta sum on 32-bit systems when too much memory would
    be used
  * Fixed zeta(0,0.5) to return correct value instead of raising
    NoConvergence exception
  * Added detection of exact zeros in gammainc(), in particular fixing
    NoConvergence error for gammainc(3,-1+1j)
  * Fixed wrong values from besseli() due to improper internal
    precision
  * Fixed bessely(0,1j) to return complex nan instead of raising
    NameError (Paul Masson)
  * Changed float() and complex() applied to an mpf or mpc to use
    rounding to nearest (or the context rounding mode) instead
    truncating
  * Fix imaginary part of gammainc(n,x), n negative odd int, x < 0
  * Added alternative "phase" color scheme to cplot()
  * Better error message for int(inf) or int(nan) (Aaron Meurer)
  * Fixed polyroots() with error=True
  * Added support to pass optional initial values to polyroots()
    (Michael Kagalenko)
  * Rewrote the Python major version selection to make it work if
    something else has redefined xrange (Arne Brys)
  * Switched documentation formula rendering to MathJax (Sergey B
    Kirpichev)
  * Fixed documentation TeX build (Sergey B Kirpichev)
  * Added PEP8 conformity testing (Sergey B Kirpichev)
  * Various fixes for the test code and test infrastructure on
    different platforms and Python versions (Sergey B Kirpichev)
  * Fixed module paths in setup.py (Aaron Meurer)
  * Documented more options for methods such as nstr() and hyper()
  * Miscellaneous corrections to the documentation (various)
* Wed May 24 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix source URL.
* Thu Sep 18 2014 toddrme2178@gmail.com
- Update to 0.19
  * Moved issue tracking to github and the main website to mpmath.org.
    Several URLs and issue numbers were updated in the documentation
    (Sergey B Kirpichev)
  * Enabled automatic testing with Travis CI (Sergey B Kirpichev)
  * Fixed many doctest issues (Sergey B Kirpichev)
  * Converted line endings to LF (Ondrej Certik)
  * Made polyroots() more robust (Ondrej Certik)
- Update to 0.18
  * Linear algebra:
  * added qr() for matrix QR factorization (contributed by Ken Allen)
  * added functions eigsy(), eighe(), eig() to compute matrix
    eigenvalues (contributed by Timo Hartmann)
  * added functions svd(), svd_r(), svd_c() for singular value
    decomposition of matrices (contributed by Timo Hartmann)
  * added calculation of Gaussian quadrature rules for various weight
    functions (contributed by Timo Hartmann)
  * improved precision selection in exp_pade() (contributed by
    Mario Pernici)
  * Special functions:
  * fixed ellippi() to return an inf instead of raising an exception
  * fixed a crash in zeta() with huge arguments
  * added functions for computing Stirling numbers
    (stirling1(), stirling2())
  * improved the computation of zeros of zeta at high precision
    (contributed by Juan Arias de Reyna)
  * fixed zeta(-x) raising an exception for tiny x
  * recognize when lerchphi() can call zeta() or polylog(),
    handling those cases faster
  * Compatibility:
  * fixed gmpy2 compatibility issues (contributed by Case Van Horsen)
  * better solutions for python 2/3 compatibility,
    using Benjamin Peterson's six.py
  * fixes to allow mpmath to run in non-sage mode when sage is available
  * support abstract base classes (contributed by Stefan Krastanov)
  * use new-style classes to improve pypy performance
  * Other:
  * added Levin, Sidi-S and Cohen/Villegas/Zagier series
    transformations (contributed by Timo Hartmann)
  * added isfinite() utility function
  * fixed a problem with bisection root-finding
  * fixed several documentation errors
  * corrected number of coefficients returned by diffs() with
    method='quad'
  * fixed repr(constant) being slow at high precision
  * made intervals hashable
- Run unit tests
* Tue Jan 31 2012 saschpe@suse.de
- Fix macro usage
- Set license to SPDX style (BSD-3-Clause)
- Package CHANGES, LICENSE and README
- Added group to doc package (SLE_11 build)
* Wed Jan  4 2012 toddrme2178@gmail.com
- version 0.17
- Cleaned up spec file formatting with spec-cleaner
- Changed source to point to upstream source URL
- Switched to .changes file
- Added documentation
* Sun Dec 20 2009 werner.ho@gmx.de
- fixed site-packages location for openSUSE 11.2
* Wed Jun 10 2009 felix.richter2@uni-rostock.de
- version 0.12
* Tue Jan  6 2009 felix.richter2@uni-rostock.de
- version 0.10
- directory fixes for opensuse 11.1
